@@ -17,16 +17,21 @@
 
 #include "autoconfig.h"
 
+#include "subtreelist.h"
+
 #include <memory>
+#include <string>
+#include <vector>
 
 #include "cstr.h"
 #include "rcldb.h"
 #include "searchdata.h"
 #include "rclquery.h"
-#include "subtreelist.h"
 #include "log.h"
+#include "rcldoc.h"
+#include "rclconfig.h"
 
-bool subtreelist(RclConfig *config, const string& _top, vector<string>& paths)
+bool subtreelist(RclConfig *config, const std::string& _top, std::vector<std::string>& paths)
 {
     std::string top(_top);
 #ifdef _WIN32
@@ -55,7 +60,7 @@ bool subtreelist(RclConfig *config, const string& _top, vector<string>& paths)
         Rcl::Doc doc;
         if (!query.getDoc(i, doc))
             break;
-        string path = fileurltolocalpath(doc.url);
+        std::string path = fileurltolocalpath(doc.url);
         if (!path.empty())
             paths.push_back(path);
     }
