@@ -4,7 +4,7 @@
  *
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2001 Ananova Ltd
- * Copyright 2002,2006,2007,2008,2009,2010,2011 Olly Betts
+ * Copyright 2002,2006,2007,2008,2009,2010,2011,2012,2015,2016,2018,2020 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,68 +22,65 @@
  * USA
  */
 
-#include <algorithm>
 #include "htmlparse.h"
-#include <stdio.h>
-#include <ctype.h>
+
+#include <algorithm>
+
+#include <cctype>
 #include <cstring>
+#include <cstdio>
+#include <iostream>
 
 using std::find;
 using std::find_if;
 using std::string;
 using std::map;
 
-inline void
-lowercase_string(string &str)
-{
-    for (string::iterator i = str.begin(); i != str.end(); ++i) {
-        *i = tolower(static_cast<unsigned char>(*i));
-    }
-}
+#define CONST_STRLEN(S) (sizeof(S"") - 1)
+
+// HTML5 legacy compatibility doctype.
+#define HTML5_LEGACY_COMPAT "about:legacy-compat"
+#define HTML5_LEGACY_COMPAT_LEN CONST_STRLEN(HTML5_LEGACY_COMPAT)
 
 map<string, unsigned int> HtmlParser::named_ents;
 
-inline static bool
-p_notdigit(char c)
-{
-    return !isdigit(static_cast<unsigned char>(c));
-}
+// These have different defs in xapian but are helpful to minimize the diffs
+#define C_tolower(c) tolower(static_cast<unsigned char>(c))
+#define C_isalnum(c) isalnum(static_cast<unsigned char>(c))
+#define C_isspace(c) isspace(static_cast<unsigned char>(c))
+#define C_isalpha(c) isalpha(static_cast<unsigned char>(c))
 
 inline static bool
-p_notxdigit(char c)
+C_isnotspace(char c)
 {
-    return !isxdigit(static_cast<unsigned char>(c));
+    return !C_isspace(c);
 }
 
-inline static bool
-p_notalnum(char c)
+static inline void
+lowercase_string(string &str)
 {
-    return !isalnum(static_cast<unsigned char>(c));
+    for (string::iterator i = str.begin(); i != str.end(); ++i) {
+        *i = C_tolower(*i);
+    }
 }
 
-inline static bool
-p_notwhitespace(char c)
-{
-    return !isspace(static_cast<unsigned char>(c));
-}
-
-inline static bool
+static inline bool
 p_nottag(char c)
 {
-    return !isalnum(static_cast<unsigned char>(c)) &&
-        c != '.' && c != '-' && c != ':'; // ':' for XML namespaces.
+    // ':' for XML namespaces.
+    return !C_isalnum(c) && c != '.' && c != '-' && c != ':';
 }
 
-inline static bool
+static inline bool
 p_whitespacegt(char c)
 {
-    return isspace(static_cast<unsigned char>(c)) || c == '>';
+    return C_isspace(c) || c == '>';
 }
 
-inline static bool
+static inline bool
 p_whitespaceeqgt(char c)
 {
-    return isspace(static_cast<unsigned char>(c)) || c == '=' || c == '>';
+    return C_isspace(c) || c == '=' || c == '>';
 }
 
 bool
@@ -95,91 +92,29 @@ HtmlParser::get_parameter(const string & param, string & value) const
     return true;
 }
 
-HtmlParser::HtmlParser()
-{
-    // RECOLL: no need to initialize these entities, we use those from
-    // myhtmlparse
-#if 0
-    static const struct ent { const char *n; unsigned int v; } ents[] = {
-#include "namedentities.h"
-        { NULL, 0 }
-    };
-    if (named_ents.empty()) {
-        const struct ent *i = ents;
-        while (i->n) {
-            named_ents[string(i->n)] = i->v;
-            ++i;
-        }
-    }
-#endif
-}
 
 void
 HtmlParser::decode_entities(string &)
 {
-    // Not used for recoll. Kept here to minimize the amount of
-    // diffs. Almost the same code in myhtmlparse except that the
+    // Not used for recoll.
+    // Almost the same code in myhtmlparse except that the
     // entity table directly holds the utf-8 strings instead of the
     // unicode positions (one less conversion).
-#if 0
-    // We need a const_iterator version of s.end() - otherwise the
-    // find() and find_if() templates don't work...
-    string::const_iterator amp = s.begin(), s_end = s.end();
-    while ((amp = find(amp, s_end, '&')) != s_end) {
-        unsigned int val = 0;
-        string::const_iterator end, p = amp + 1;
-        if (p != s_end && *p == '#') {
-            p++;
-            if (p != s_end && (*p == 'x' || *p == 'X')) {
-                // hex
-                p++;
-                end = find_if(p, s_end, p_notxdigit);
-                sscanf(s.substr(p - s.begin(), end - p).c_str(), "%x", &val);
-            } else {
-                // number
-                end = find_if(p, s_end, p_notdigit);
-                val = atoi(s.substr(p - s.begin(), end - p).c_str());
-            }
-        } else {
-            end = find_if(p, s_end, p_notalnum);
-            string code = s.substr(p - s.begin(), end - p);
-            map<string, unsigned int>::const_iterator i;
-            i = named_ents.find(code);
-            if (i != named_ents.end()) val = i->second;
-        }
-        if (end < s_end && *end == ';') end++;
-        if (val) {
-            string::size_type amp_pos = amp - s.begin();
-            if (val < 0x80) {
-                s.replace(amp_pos, end - amp, 1u, char(val));
-            } else {
-                // Convert unicode value val to UTF-8.
-                char seq[4];
-                unsigned len = Xapian::Unicode::nonascii_to_utf8(val, seq);
-                s.replace(amp_pos, end - amp, seq, len);
-            }
-            s_end = s.end();
-            // We've modified the string, so the iterators are no longer
-            // valid...
-            amp = s.begin() + amp_pos + 1;
-        } else {
-            amp = end;
-        }
-    }
-#endif
 }
 
 void
 HtmlParser::parse_html(const string &body)
 {
+    string::const_iterator begin_after_bom = body.begin();
+
     in_script = false;
 
     parameters.clear();
-    string::const_iterator start = body.begin();
+    string::const_iterator start = begin_after_bom;
 
     while (true) {
         // Skip through until we find an HTML tag, a comment, or the end of
-        // document.  Ignore isolated occurrences of `<' which don't start
+        // document.  Ignore isolated occurrences of '<' which don't start
         // a tag or comment.    
         string::const_iterator p = start;
         while (true) {
@@ -188,13 +123,12 @@ HtmlParser::parse_html(const string &body)
             unsigned char ch = *(p + 1);
 
             // Tag, closing tag, or comment (or SGML declaration).
-            if ((!in_script && isalpha(ch)) || ch == '/' || ch == '!') break;
+            if ((!in_script && C_isalpha(ch)) || ch == '/' || ch == '!') break;
 
             if (ch == '?') {
                 // PHP code or XML declaration.
                 // XML declaration is only valid at the start of the first line.
-                // FIXME: need to deal with BOMs...
-                if (p != body.begin() || body.size() < 20) break;
+                if (p != begin_after_bom || body.size() < 20) break;
 
                 // XML declaration looks something like this:
                 // <?xml version="1.0" encoding="UTF-8"?>
@@ -225,67 +159,154 @@ HtmlParser::parse_html(const string &body)
                 size_t enc_end = decl.find(quote, enc);
 
                 if (enc != string::npos)
-                    charset = decl.substr(enc, enc_end - enc);
+                    charset.assign(decl, enc, enc_end - enc);
 
                 break;
             }
-            p++;
+            ++p;
         }
 
         // Process text up to start of tag.
-        if (p > start || p == body.end()) {
-            string text = body.substr(start - body.begin(), p - start);
+        if (p > start) {
+            string text(body, start - body.begin(), p - start);
             decode_entities(text);
             process_text(text);
         }
 
-        if (p == body.end()) {
-            do_eof();
-            break;
-        }
+        if (p == body.end()) break;
 
         start = p + 1;
    
         if (start == body.end()) break;
 
-        if (*start == '!') {
-            if (++start == body.end()) break;
-            if (++start == body.end()) break;
-            // comment or SGML declaration
-            if (*(start - 1) == '-' && *start == '-') {
-                ++start;
-                string::const_iterator close = find(start, body.end(), '>');
-                // An unterminated comment swallows rest of document
-                // (like Netscape, but unlike MSIE IIRC)
-                if (close == body.end()) break;
+	if (*start == '!') {
+	    if (++start == body.end()) break;
 
-                p = close;
-                // look for -->
-                while (p != body.end() && (*(p - 1) != '-' || *(p - 2) != '-'))
-                    p = find(p + 1, body.end(), '>');
+	    // Comment, SGML declaration, or HTML5 DTD.
+	    char first_ch = *start;
+	    if (++start == body.end()) break;
+	    if (first_ch == '-' && *start == '-') {
+		++start;
+		string::const_iterator close = find(start, body.end(), '>');
+		// An unterminated comment swallows rest of document
+		// (like Netscape, but unlike MSIE IIRC)
+		if (close == body.end()) break;
 
-                if (p != body.end()) {
-                    // Check for htdig's "ignore this bit" comments.
-                    if (p - start == 15 && string(start, p - 2) == "htdig_noindex") {
-                        string::size_type i;
-                        i = body.find("<!--/htdig_noindex-->", p + 1 - body.begin());
-                        if (i == string::npos) break;
-                        start = body.begin() + i + 21;
-                        continue;
-                    }
-                    // If we found --> skip to there.
-                    start = p;
-                } else {
-                    // Otherwise skip to the first > we found (as Netscape does).
-                    start = close;
-                }
-            } else {
-                // just an SGML declaration, perhaps giving the DTD - ignore it
-                start = find(start - 1, body.end(), '>');
-                if (start == body.end()) break;
-            }
-            ++start;
-        } else if (*start == '?') {
+		p = close;
+		// look for -->
+		while (p != body.end() && (*(p - 1) != '-' || *(p - 2) != '-'))
+		    p = find(p + 1, body.end(), '>');
+
+		if (p != body.end()) {
+		    // Check for htdig's "ignore this bit" comments.
+		    if (p - start == CONST_STRLEN("htdig_noindex") + 2 &&
+			memcmp(&*start, "htdig_noindex",
+			       CONST_STRLEN("htdig_noindex")) == 0) {
+			auto i = body.find("<!--/htdig_noindex-->",
+					   p + 1 - body.begin());
+			if (i == string::npos) break;
+			start = body.begin() + i +
+			    CONST_STRLEN("<!--/htdig_noindex-->");
+			continue;
+		    }
+		    // Check for udmcomment (similar to htdig's)
+		    if (p - start == CONST_STRLEN("UdmComment") + 2 &&
+			memcmp(&*start, "UdmComment",
+			       CONST_STRLEN("UdmComment")) == 0) {
+			auto i = body.find("<!--/UdmComment-->",
+					   p + 1 - body.begin());
+			if (i == string::npos) break;
+			start = body.begin() + i +
+			    CONST_STRLEN("<!--/UdmComment-->");
+			continue;
+		    }
+		    // If we found --> skip to there.
+		    start = p;
+		} else {
+		    // Otherwise skip to the first > we found (as Netscape does).
+		    start = close;
+		}
+	    } else if (first_ch == '[' &&
+		       body.size() - (start - body.begin()) > 6 &&
+		       body.compare(start - body.begin(), 6, "CDATA[", 6) == 0) {
+		start += 6;
+		string::size_type b = start - body.begin();
+		string::size_type i;
+		i = body.find("]]>", b);
+		string text(body, b, i - b);
+		process_text(text);
+		if (i == string::npos) break;
+		start = body.begin() + i + 2;
+	    } else if (C_tolower(first_ch) == 'd' &&
+		       body.end() - start > 6 &&
+		       C_tolower(start[0]) == 'o' &&
+		       C_tolower(start[1]) == 'c' &&
+		       C_tolower(start[2]) == 't' &&
+		       C_tolower(start[3]) == 'y' &&
+		       C_tolower(start[4]) == 'p' &&
+		       C_tolower(start[5]) == 'e' &&
+		       C_isspace(start[6])) {
+		// DOCTYPE declaration.
+		start += 7;
+		while (start != body.end() && C_isspace(*start)) {
+		    ++start;
+		}
+		if (start == body.end()) break;
+		if (body.end() - start >= 5 &&
+		    C_tolower(start[0]) == 'h' &&
+		    C_tolower(start[1]) == 't' &&
+		    C_tolower(start[2]) == 'm' &&
+		    C_tolower(start[3]) == 'l' &&
+		    (start[4] == '>' || C_isspace(start[4]))) {
+		    start += 4;
+
+		    // HTML doctype.
+		    while (start != body.end() && C_isspace(*start)) {
+			++start;
+		    }
+		    if (start == body.end()) break;
+
+		    if (*start == '>') {
+			// <!DOCTYPE html>
+			// Default charset for HTML5 is UTF-8.
+			charset = "utf-8";
+		    }
+		} else if (body.end() - start >= 29 &&
+			   C_tolower(start[0]) == 's' &&
+			   C_tolower(start[1]) == 'y' &&
+			   C_tolower(start[2]) == 's' &&
+			   C_tolower(start[3]) == 't' &&
+			   C_tolower(start[4]) == 'e' &&
+			   C_tolower(start[5]) == 'm' &&
+			   C_isspace(start[6])) {
+		    start += 7;
+		    while (start != body.end() && C_isspace(*start)) {
+			++start;
+		    }
+		    size_t left = body.end() - start;
+		    if (left >= HTML5_LEGACY_COMPAT_LEN + 3 &&
+			(*start == '\'' || *start == '"') &&
+			start[HTML5_LEGACY_COMPAT_LEN + 1] == *start &&
+			body.compare(start - body.begin() + 1,
+				     HTML5_LEGACY_COMPAT_LEN,
+				     HTML5_LEGACY_COMPAT,
+				     HTML5_LEGACY_COMPAT_LEN) == 0) {
+			// HTML5 legacy compatibility doctype:
+			// <!DOCTYPE html SYSTEM "about:legacy-compat">
+			start += HTML5_LEGACY_COMPAT_LEN + 2;
+			// Default charset for HTML5 is UTF-8.
+			charset = "utf-8";
+		    }
+		}
+		start = find(start - 1, body.end(), '>');
+		if (start == body.end()) break;
+	    } else {
+		// Some other SGML declaration - ignore it.
+		start = find(start - 1, body.end(), '>');
+		if (start == body.end()) break;
+	    }
+	    ++start;
+	} else if (*start == '?') {
             if (++start == body.end()) break;
             // PHP - swallow until ?> or EOF
             start = find(start + 1, body.end(), '>');
@@ -294,21 +315,31 @@ HtmlParser::parse_html(const string &body)
             while (start != body.end() && *(start - 1) != '?')
                 start = find(start + 1, body.end(), '>');
 
-            // unterminated PHP swallows rest of document (rather arbitrarily
-            // but it avoids polluting the database when things go wrong)
-            if (start != body.end()) ++start;
+	    if (start == body.end()) {
+		// The closing ?> at the end of a file is optional so ignore
+		// the rest of the document if there isn't one:
+		// https://www.php.net/basic-syntax.instruction-separation
+	    } else {
+		// PHP ignores an immediately trailing newline after the
+		// closing tag:
+		// https://www.php.net/basic-syntax.instruction-separation
+		// Testing shows \n, \r and \r\n are skipped.
+		++start;
+		if (*start == '\r') ++start;
+		if (*start == '\n') ++start;
+	    }
         } else {
             // opening or closing tag
             int closing = 0;
 
             if (*start == '/') {
                 closing = 1;
-                start = find_if(start + 1, body.end(), p_notwhitespace);
+                start = find_if(start + 1, body.end(), C_isnotspace);
             }
           
             p = start;
             start = find_if(start, body.end(), p_nottag);
-            string tag = body.substr(p - body.begin(), start - p);
+            string tag(body, p - body.begin(), start - p);
             // convert tagname to lowercase
             lowercase_string(tag);
 
@@ -341,26 +372,30 @@ HtmlParser::parse_html(const string &body)
 
                     name.assign(body, start - body.begin(), name_len);
 
-                    p = find_if(p, body.end(), p_notwhitespace);
+                    p = find_if(p, body.end(), C_isnotspace);
 
                     start = p;
                     if (start != body.end() && *start == '=') {
-                        start = find_if(start + 1, body.end(), p_notwhitespace);
+                        start = find_if(start + 1, body.end(), C_isnotspace);
 
                         p = body.end();
 
                         int quote = *start;
                         if (quote == '"' || quote == '\'') {
-                            start++;
+                            ++start;
                             p = find(start, body.end(), quote);
                         }
 
-                        if (p == body.end()) {
-                            // unquoted or no closing quote
-                            p = find_if(start, body.end(), p_whitespacegt);
-                        }
-                        value.assign(body, start - body.begin(), p - start);
-                        start = find_if(p, body.end(), p_notwhitespace);
+			if (p != body.end()) {
+			    // quoted
+			    value.assign(body, start - body.begin(), p - start);
+			    ++p;
+			} else {
+			    // unquoted or no closing quote
+			    p = find_if(start, body.end(), p_whitespacegt);
+			    value.assign(body, start - body.begin(), p - start);
+			}
+                        start = find_if(p, body.end(), C_isnotspace);
 
                         if (!name.empty()) {
                             // convert parameter name to lowercase
@@ -374,7 +409,7 @@ HtmlParser::parse_html(const string &body)
 #if 0
                 cout << "<" << tag;
                 map<string, string>::const_iterator x;
-                for (x = parameters.begin(); x != parameters.end(); x++) {
+                for (x = parameters.begin(); x != parameters.end(); ++x) {
                     cout << " " << x->first << "=\"" << x->second << "\"";
                 }
                 cout << ">\n";
