@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2021 J.F.Dockes
+/* Copyright (C) 2005-2025 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as published by
  *   the Free Software Foundation; either version 2.1 of the License, or
@@ -47,13 +47,11 @@
 #include <qpushbutton.h>
 #include <qstringlist.h>
 #include <qcombobox.h>
+#include <QDebug>
+#include <QAbstractButton>
 
 #include "smallut.h"
 
-#ifdef ENABLE_XMLCONF
-#include "picoxml.h"
-#endif
-
 namespace confgui {
 
 // Main layout spacing
@@ -76,7 +74,9 @@ ConfTabsW::ConfTabsW(QWidget *parent, const QString& title, ConfLinkFact *fact)
     setWindowTitle(title);
     tabWidget = new QTabWidget;
 
-    buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    
+    buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok |QDialogButtonBox::Apply |
+                                     QDialogButtonBox::Cancel);
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
     mainLayout->setSpacing(spacing);
@@ -89,6 +89,8 @@ ConfTabsW::ConfTabsW(QWidget *parent, const QString& title, ConfLinkFact *fact)
 
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(acceptChanges()));
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(rejectChanges()));
+    connect(buttonBox, SIGNAL(clicked(QAbstractButton *)),
+            this, SLOT(buttonClicked(QAbstractButton *)));
 }
 
 void ConfTabsW::hideButtons()
@@ -97,6 +99,19 @@ void ConfTabsW::hideButtons()
         buttonBox->hide();
 }
 
+bool ConfTabsW::modified()
+{
+    for (auto& entry : m_panels) {
+        if (entry->modified())
+            return true;
+    }
+    for (auto& entry : m_widgets) {
+        if (entry->modified())
+            return true;
+    }
+    return false;
+}
+
 void ConfTabsW::acceptChanges()
 {
     for (auto& entry : m_panels) {
@@ -110,6 +125,21 @@ void ConfTabsW::acceptChanges()
         close();
 }
 
+void ConfTabsW::buttonClicked(QAbstractButton* button)
+{
+    // Testing the button text does not seem very reliable. We should create and store the buttons
+    // and add them to the box, then test which it is.
+    if (button->text() != tr("Apply"))
+        return;
+    for (auto& entry : m_panels) {
+        entry->storeValues();
+    }
+    for (auto& entry : m_widgets) {
+        entry->storeValues();
+    }
+    emit sig_prefsChanged();
+}
+
 void ConfTabsW::rejectChanges()
 {
     reloadPanels();
@@ -294,6 +324,14 @@ void ConfPanelW::endOfList()
     m_vboxlayout->addStretch(2);
 }
 
+bool ConfPanelW::modified()
+{
+    for (auto& widgetp : m_params) {
+        if (widgetp->modified())
+            return true;
+    }
+    return false;
+}
 void ConfPanelW::storeValues()
 {
     for (auto& widgetp : m_params) {
@@ -399,6 +437,8 @@ ConfParamIntW::ConfParamIntW(
     int minvalue, int maxvalue, int defaultvalue)
     : ConfParamW(varnm, parent, cflink), m_defaultvalue(defaultvalue)
 {
+    //qDebug() << "ConfParamIntW: nm [" << varnm << "] min " << minvalue << " max " <<
+    //    maxvalue << " def " << defaultvalue;;
     if (!createCommon(lbltxt, tltptxt)) {
         return;
     }
@@ -420,9 +460,15 @@ void ConfParamIntW::storeValue()
 {
     if (m_origvalue != m_sb->value()) {
         setValue(m_sb->value());
+        m_origvalue = m_sb->value();
     }
 }
 
+bool ConfParamIntW::modified()
+{
+    return m_origvalue != m_sb->value();
+}
+
 void ConfParamIntW::loadValue()
 {
     std::string s;
@@ -457,10 +503,15 @@ ConfParamStrW::ConfParamStrW(
 
 void ConfParamStrW::storeValue()
 {
-    if (m_origvalue.compare(m_le->text())) {
+    if (m_origvalue != m_le->text()) {
         setValue(m_le->text());
+        m_origvalue = m_le->text();
     }
 }
+bool ConfParamStrW::modified()
+{
+    return m_origvalue != m_le->text();
+}
 
 void ConfParamStrW::loadValue()
 {
@@ -512,10 +563,15 @@ void ConfParamCStrW::setList(const QStringList& sl)
 
 void ConfParamCStrW::storeValue()
 {
-    if (m_origvalue.compare(m_cmb->currentText())) {
+    if (m_origvalue != m_cmb->currentText()) {
         setValue(m_cmb->currentText());
+        m_origvalue = m_cmb->currentText();
     }
 }
+bool ConfParamCStrW::modified()
+{
+    return m_origvalue != m_cmb->currentText();
+}
 
 void ConfParamCStrW::loadValue()
 {
@@ -574,8 +630,13 @@ void ConfParamBoolW::storeValue()
 {
     if (m_origvalue != m_cb->isChecked()) {
         setValue(m_cb->isChecked());
+        m_origvalue = m_cb->isChecked();
     }
 }
+bool ConfParamBoolW::modified()
+{
+    return m_origvalue != m_cb->isChecked();
+}
 
 void ConfParamBoolW::loadValue()
 {
@@ -622,10 +683,15 @@ ConfParamFNW::ConfParamFNW(
 
 void ConfParamFNW::storeValue()
 {
-    if (m_origvalue.compare(m_le->text())) {
+    if (m_origvalue != m_le->text()) {
         setValue(m_le->text());
+        m_origvalue = m_le->text();
     }
 }
+bool ConfParamFNW::modified()
+{
+    return m_origvalue != m_le->text();
+}
 
 void ConfParamFNW::loadValue()
 {
@@ -768,10 +834,15 @@ std::string ConfParamSLW::listToString()
 void ConfParamSLW::storeValue()
 {
     std::string s = listToString();
-    if (s.compare(m_origvalue)) {
+    if (m_origvalue != s) {
         m_cflink->set(s);
+        m_origvalue = s;
     }
 }
+bool ConfParamSLW::modified()
+{
+    return listToString() != m_origvalue;
+}
 
 void ConfParamSLW::loadValue()
 {
@@ -903,219 +974,4 @@ void ConfParamCSLW::showInputDialog()
     performInsert(s);
 }
 
-
-#ifdef ENABLE_XMLCONF
-
-static QString u8s2qs(const std::string us)
-{
-    return QString::fromUtf8(us.c_str());
-}
-
-static const std::string& mapfind(
-    const std::string& nm, const std::map<std::string, std::string>& mp)
-{
-    static std::string strnull;
-    std::map<std::string, std::string>::const_iterator it = mp.find(nm);
-    if (it == mp.end()) {
-        return strnull;
-    }
-    return it->second;
-}
-
-static std::string looksLikeAssign(const std::string& data)
-{
-    //LOGDEB("looksLikeAssign. data: [" << data << "]");
-    std::vector<std::string> toks;
-    stringToTokens(data, toks, "\n\r\t ");
-    if (toks.size() >= 2 && !toks[1].compare("=")) {
-        return toks[0];
-    }
-    return std::string();
-}
-
-ConfTabsW *xmlToConfGUI(const std::string& xml, std::string& toptext,
-                        ConfLinkFact* lnkf, QWidget *parent)
-{
-    //LOGDEB("xmlToConfGUI: [" << xml << "]");
-
-    class XMLToConfGUI : public PicoXMLParser {
-    public:
-        XMLToConfGUI(const std::string& x, ConfLinkFact *lnkf, QWidget *parent)
-            : PicoXMLParser(x), m_lnkfact(lnkf), m_parent(parent),
-              m_idx(0), m_hadTitle(false), m_hadGroup(false) {
-        }
-        virtual ~XMLToConfGUI() {}
-
-        virtual void startElement(const std::string& tagname,
-                                  const std::map<std::string, std::string>& attrs) {
-            if (!tagname.compare("var")) {
-                m_curvar = mapfind("name", attrs);
-                m_curvartp = mapfind("type", attrs);
-                m_curvarvals = mapfind("values", attrs);
-                //LOGDEB("Curvar: " << m_curvar);
-                if (m_curvar.empty() || m_curvartp.empty()) {
-                    throw std::runtime_error(
-                        "<var> with no name attribute or no type ! nm [" +
-                        m_curvar + "] tp [" + m_curvartp + "]");
-                } else {
-                    m_brief.clear();
-                    m_descr.clear();
-                }
-            } else if (!tagname.compare("filetitle") ||
-                       !tagname.compare("grouptitle")) {
-                m_other.clear();
-            }
-        }
-
-        virtual void endElement(const std::string& tagname) {
-            if (!tagname.compare("var")) {
-                if (!m_hadTitle) {
-                    m_w = new ConfTabsW(m_parent, "Teh title", m_lnkfact);
-                    m_hadTitle = true;
-                }
-                if (!m_hadGroup) {
-                    m_idx = m_w->addPanel("Group title");
-                    m_hadGroup = true;
-                }
-                ConfTabsW::ParamType paramtype;
-                if (!m_curvartp.compare("bool")) {
-                    paramtype = ConfTabsW::CFPT_BOOL;
-                } else if (!m_curvartp.compare("int")) {
-                    paramtype = ConfTabsW::CFPT_INT;
-                } else if (!m_curvartp.compare("string")) {
-                    paramtype = ConfTabsW::CFPT_STR;
-                } else if (!m_curvartp.compare("cstr")) {
-                    paramtype = ConfTabsW::CFPT_CSTR;
-                } else if (!m_curvartp.compare("cstrl")) {
-                    paramtype = ConfTabsW::CFPT_CSTRL;
-                } else if (!m_curvartp.compare("fn")) {
-                    paramtype = ConfTabsW::CFPT_FN;
-                } else if (!m_curvartp.compare("dfn")) {
-                    paramtype = ConfTabsW::CFPT_FN;
-                } else if (!m_curvartp.compare("strl")) {
-                    paramtype = ConfTabsW::CFPT_STRL;
-                } else if (!m_curvartp.compare("dnl")) {
-                    paramtype = ConfTabsW::CFPT_DNL;
-                } else {
-                    throw std::runtime_error("Bad type " + m_curvartp +
-                                             " for " + m_curvar);
-                }
-                rtrimstring(m_brief, " .");
-                switch (paramtype) {
-                case ConfTabsW::CFPT_BOOL: {
-                    int def = atoi(m_curvarvals.c_str());
-                    m_w->addParam(m_idx, paramtype, u8s2qs(m_curvar),
-                                  u8s2qs(m_brief), u8s2qs(m_descr), def);
-                    break;
-                }
-                case ConfTabsW::CFPT_INT: {
-                    std::vector<std::string> vals;
-                    stringToTokens(m_curvarvals, vals);
-                    int min = 0, max = 0, def = 0;
-                    if (vals.size() >= 3) {
-                        min = atoi(vals[0].c_str());
-                        max = atoi(vals[1].c_str());
-                        def = atoi(vals[2].c_str());
-                    }
-                    QStringList *sldef = 0;
-                    sldef = (QStringList*)(((char*)sldef) + def);
-                    m_w->addParam(m_idx, paramtype, u8s2qs(m_curvar),
-                                  u8s2qs(m_brief), u8s2qs(m_descr),
-                                  min, max, sldef);
-                    break;
-                }
-                case  ConfTabsW::CFPT_CSTR:
-                case ConfTabsW::CFPT_CSTRL: {
-                    std::vector<std::string> cstrl;
-                    stringToTokens(neutchars(m_curvarvals, "\n\r"), cstrl);
-                    QStringList qstrl;
-                    for (unsigned int i = 0; i < cstrl.size(); i++) {
-                        qstrl.push_back(u8s2qs(cstrl[i]));
-                    }
-                    m_w->addParam(m_idx, paramtype, u8s2qs(m_curvar),
-                                  u8s2qs(m_brief), u8s2qs(m_descr),
-                                  0, 0, &qstrl);
-                    break;
-                }
-                default:
-                    m_w->addParam(m_idx, paramtype, u8s2qs(m_curvar),
-                                  u8s2qs(m_brief), u8s2qs(m_descr));
-                }
-            } else if (!tagname.compare("filetitle")) {
-                m_w = new ConfTabsW(m_parent, u8s2qs(m_other), m_lnkfact);
-                m_hadTitle = true;
-                m_other.clear();
-            } else if (!tagname.compare("grouptitle")) {
-                if (!m_hadTitle) {
-                    m_w = new ConfTabsW(m_parent, "Teh title", m_lnkfact);
-                    m_hadTitle = true;
-                }
-                // Get rid of "parameters" in the title, it's not interesting
-                // and this makes our tab headers smaller.
-                std::string ps{"parameters"};
-                std::string::size_type pos = m_other.find(ps);
-                if (pos != std::string::npos) {
-                    m_other = m_other.replace(pos, ps.size(), "");
-                }
-                m_idx = m_w->addPanel(u8s2qs(m_other));
-                m_hadGroup = true;
-                m_other.clear();
-            } else if (!tagname.compare("descr")) {
-            } else if (!tagname.compare("brief")) {
-                m_brief = neutchars(m_brief, "\n\r");
-            }
-        }
-
-        virtual void characterData(const std::string& data) {
-            if (!tagStack().back().compare("brief")) {
-                m_brief += data;
-            } else if (!tagStack().back().compare("descr")) {
-                m_descr += data;
-            } else if (!tagStack().back().compare("filetitle") ||
-                       !tagStack().back().compare("grouptitle")) {
-                // We don't want \n in there
-                m_other += neutchars(data, "\n\r");
-                m_other += " ";
-            } else if (!tagStack().back().compare("confcomments")) {
-                std::string nvarname = looksLikeAssign(data);
-                if (!nvarname.empty() && nvarname.compare(m_curvar)) {
-                    std::cerr << "Var assigned [" << nvarname << "] mismatch "
-                        "with current variable [" << m_curvar << "]\n";
-                }
-                m_toptext += data;
-            }
-        }
-
-        ConfTabsW *m_w;
-
-        ConfLinkFact *m_lnkfact;
-        QWidget *m_parent;
-        int m_idx;
-        std::string m_curvar;
-        std::string m_curvartp;
-        std::string m_curvarvals;
-        std::string m_brief;
-        std::string m_descr;
-        std::string m_other;
-        std::string m_toptext;
-        bool m_hadTitle;
-        bool m_hadGroup;
-    };
-
-    XMLToConfGUI parser(xml, lnkf, parent);
-    try {
-        if (!parser.parse()) {
-            std::cerr << "Parse failed: " << parser.getLastErrorMessage() << "\n";
-            return 0;
-        }
-    } catch (const std::runtime_error& e) {
-        std::cerr << e.what() << "\n";
-        return 0;
-    }
-    toptext = parser.m_toptext;
-    return parser.m_w;
-}
-
-#endif /* ENABLE_XMLCONF */
-
 } // Namespace confgui
