@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 J.F.Dockes 
+/* Copyright (C) 2005-2023 J.F.Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -166,7 +166,9 @@ private:
     // Running js after page load. Sometimes we don't want to do it on the first event (which may be
     // a reset), hence the countdown.
     QString m_js;
-    int m_js_countdown{0};
+#if defined(USING_WEBENGINE)
+	int m_js_countdown{0};
+#endif // Webengine
     RclMain   *m_rclmain{0};
     bool m_ismainres{true};
 
@@ -178,29 +180,6 @@ private:
     bool scrollIsAtBottom();
 };
 
-#ifdef USING_WEBENGINE
-
-// Subclass the page to hijack the link clicks
-class RclWebPage : public QWebEnginePage {
-    Q_OBJECT
-
-public:
-    RclWebPage(ResList *parent) 
-        : QWebEnginePage((QWidget *)parent), m_reslist(parent) {}
-
-protected:
-    virtual bool acceptNavigationRequest(
-        const QUrl& url, NavigationType tp, bool isMainFrame);
-private:
-    ResList *m_reslist;
-};
-
-#else // Using Qt Webkit
-
-#define RclWebPage QWebPage
-
-#endif
-
 class PlainToRichQtReslist : public PlainToRich {
 public:
     virtual std::string startMatch(unsigned int idx);
