@@ -445,7 +445,8 @@ void RecollModel::saveAsCSV(std::fstream& fp)
 {
     if (!m_source)
         return;
-
+    m_source->setqquantum(30000);
+    
     int cols = columnCount();
     vector<string> tokens;
 
@@ -467,6 +468,7 @@ void RecollModel::saveAsCSV(std::fstream& fp)
         csv = stringsToCSV(tokens);
         fp << csv << "\n";
     }
+    m_source->setqquantum(100);
 }
 
 // This gets called when the column headers are clicked
@@ -485,8 +487,7 @@ void RecollModel::sort(int column, Qt::SortOrder order)
             QTimer::singleShot(0, m_table, SLOT(resetSort()));
             return;
         }
-        if (!stringlowercmp("date", spec.field) ||
-            !stringlowercmp("datetime", spec.field))
+        if (!stringlowercmp("date", spec.field) || !stringlowercmp("datetime", spec.field))
             spec.field = "mtime";
         spec.desc = (order != Qt::AscendingOrder);
     }
@@ -652,7 +653,8 @@ void ResTable::init(QStringList _ifields)
     
     connect(tableView, SIGNAL(customContextMenuRequested(const QPoint&)),
             this, SLOT(createPopupMenu(const QPoint&)));
-
+    connect(tableView, SIGNAL(entered(const QModelIndex&)),
+            this, SLOT(tableView_entered(const QModelIndex&)));
     QHeaderView *header = tableView->horizontalHeader();
     if (header) {
         if (_ifields.empty()) {
@@ -1006,10 +1008,10 @@ void ResTable::onTableView_currentChanged(const QModelIndex& index)
     if (!displaydone && showmeta) {
         m_pager->displaySingleDoc(theconfig, m_detaildocnum, m_detaildoc, m_model->m_hdata);
     }
-    emit(detailDocChanged(doc, m_model->getDocSource()));
+    emit detailDocChanged(doc, m_model->getDocSource());
 }
 
-void ResTable::on_tableView_entered(const QModelIndex& index)
+void ResTable::tableView_entered(const QModelIndex& index)
 {
     LOGDEB2("ResTable::on_tableView_entered(" << index.row() << ", "  <<
             index.column() << ")\n");
@@ -1042,20 +1044,24 @@ void ResTable::resetSource()
     readDocSource();
 }
 
+
 void ResTable::saveAsCSV()
 {
+    static const QString csvprevdirkey("/Recoll/prefs/restableAsCSVPDir");;
     LOGDEB("ResTable::saveAsCSV\n");
     if (!m_model)
         return;
-    QString s = QFileDialog::getSaveFileName(
-        this, tr("Save table to CSV file"), path2qs(path_home()));
+    QSettings settings;
+    QString s = QFileDialog::getSaveFileName(this, tr("Save table to CSV file"),
+                                             settings.value(csvprevdirkey).toString());
     if (s.isEmpty())
         return;
+    QDir cdir;
+    settings.setValue(csvprevdirkey, cdir.absoluteFilePath(s));
     std::string tofile = qs2path(s);
     std::fstream fp;
-    if (!path_streamopen(tofile, std::ios::out|std::ios::trunc,fp)) {
-        QMessageBox::warning(0, "Recoll",
-                             tr("Can't open/create file: ") + s);
+    if (!path_streamopen(tofile, std::ios::out|std::ios::trunc, fp)) {
+        QMessageBox::warning(0, "Recoll", tr("Can't open/create file: ") + s);
         return;
     }
     m_model->saveAsCSV(fp);
@@ -1065,8 +1071,7 @@ void ResTable::saveAsCSV()
 // This is called when the sort order is changed from another widget
 void ResTable::onSortDataChanged(DocSeqSortSpec spec)
 {
-    LOGDEB("ResTable::onSortDataChanged: [" << spec.field << "] desc " <<
-           spec.desc << "\n");
+    LOGDEB("ResTable::onSortDataChanged: [" << spec.field << "] desc " << spec.desc << "\n");
     QHeaderView *header = tableView->horizontalHeader();
     if (!header || !m_model)
         return;
@@ -1135,7 +1140,7 @@ void ResTable::onLinkClicked(const QUrl &qurl)
     switch (what) {
         // Open abstract/snippets window
     case 'A':
-        emit(showSnippets(m_detaildoc));
+        emit showSnippets(m_detaildoc);
         break;
     case 'D':
     {
