@@ -1,4 +1,4 @@
-/* Copyright (C) 2006-2022 J.F.Dockes
+/* Copyright (C) 2006-2025 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -57,8 +57,6 @@
 #include "scbase.h"
 #include "base64.h"
 
-using namespace std;
-
 // If text does not end with space, return last (partial) word and its start offset (>=0) else
 // return -1
 static int getPartialWord(const QString& txt, QString& word)
@@ -151,7 +149,7 @@ QVariant RclCompleterModel::data(const QModelIndex &index, int role) const
 // list. Otherwise, list a partial word against history and index and fill the model
 void RclCompleterModel::onPartialWord(int tp, const QString& _qtext, const QString& qpartial)
 {
-    string partial = qs2u8s(qpartial);
+    std::string partial = qs2u8s(qpartial);
     QString qtext = _qtext.trimmed();
     bool onlyspace = qtext.isEmpty();
     LOGDEB1("RclCompleterModel::onPartialWord: [" << partial << "] onlyspace "<< onlyspace << "\n");
@@ -186,10 +184,9 @@ void RclCompleterModel::onPartialWord(int tp, const QString& _qtext, const QStri
     // expensive
     int mintermsizeforexpand = o_index_stripchars ? 1 : 2;
     if (qpartial.trimmed().size() >= mintermsizeforexpand &&
-        partial.find_first_of("[?*") == string::npos) {
+        partial.find_first_of("[?*") == std::string::npos) {
         Rcl::TermMatchResult rclmatches;
-        if (!rcldb->termMatch(Rcl::Db::ET_WILD, string(),
-                              partial + "*", rclmatches, maxdbtermmatch)) {
+        if (!rcldb->termMatch(Rcl::Db::ET_WILD, "", partial + "*", rclmatches, maxdbtermmatch)) {
             LOGDEB1("RclCompleterModel: termMatch failed: [" << partial + "*" << "]\n");
         } else {
             LOGDEB1("RclCompleterModel: termMatch cnt: " << rclmatches.entries.size() << '\n');
@@ -244,11 +241,20 @@ void SSearch::init()
             SLOT(onCompletionActivated(const QString&)));
 
     connect(historyPB, SIGNAL(clicked()), this, SLOT(onHistoryClicked()));
+
+    int searchtype = prefs.ssearchTypSav ? prefs.ssearchTyp : SSearch::SST_LANG;
+    onSearchTypeChanged(searchtype);
+    
     setupButtons();
     onNewShortcuts();
     connect(&SCBase::scBase(), SIGNAL(shortcutsChanged()),this, SLOT(onNewShortcuts()));
 }
 
+SSearch::SSearchType SSearch::getSearchType()
+{
+    return (SSearchType)searchTypCMB->currentIndex();
+}
+
 void SSearch::onNewShortcuts()
 {
     SETSHORTCUT(this, "ssearch:197", tr("Simple search"), tr("History"),
@@ -391,6 +397,7 @@ void SSearch::restoreText(bool startsearch)
         QTimer::singleShot(0, this, SLOT(startSimpleSearch()));
     }
 }
+
 void SSearch::onCompletionActivated(const QString& text)
 {
     LOGDEB("SSearch::onCompletionActivated: queryText [" <<
@@ -414,7 +421,7 @@ void SSearch::searchTextEdited(const QString& text)
     LOGDEB1("SSearch::searchTextEdited: text [" << qs2u8s(text) << "]\n");
     QString pword;
     int cs = getPartialWord(currentText(), pword);
-    int tp = searchTypCMB->currentIndex();
+    int tp = getSearchType();
 
     m_savedEditText = text.left(cs);
     LOGDEB1("SSearch::searchTextEdited: cs " <<cs<<" pword ["<< qs2u8s(pword) <<
@@ -443,18 +450,17 @@ void SSearch::searchTextChanged(const QString& text)
 
 void SSearch::onSearchTypeChanged(int typ)
 {
-    LOGDEB1("Search type now " << typ << "\n");
+    LOGDEB1("SSearch::onSearchTypeChanged: type now " << typ << "\n");
 
-    // This may come from the menus or the combobox. Ensure that
-    // things are in sync. No loop because we are connected to
-    // combobox or menu activated(), not currentIndexChanged()
+    // This may come from the menus or the combobox. Ensure that things are in sync. No loop because
+    // we are connected to combobox or menu activated(), not currentIndexChanged()
     searchTypCMB->setCurrentIndex(typ);
     
     // Adjust context help
     if (typ == SST_LANG) {
-        HelpClient::installMap((const char *)this->objectName().toUtf8(), "RCL.SEARCH.LANG");
+        HelpClient::installMap(qs2u8s(objectName()), "RCL.SEARCH.LANG");
     } else {
-        HelpClient::installMap((const char *)this->objectName().toUtf8(), "RCL.SEARCH.GUI.SIMPLE");
+        HelpClient::installMap(qs2u8s(objectName()), "RCL.SEARCH.GUI.SIMPLE");
     }
     // Also fix tooltips
     switch (typ) {
@@ -516,7 +522,7 @@ void SSearch::startSimpleSearch()
         && !queryText->completer()->currentCompletion().isEmpty()) {
         return;
     }
-    string u8 = qs2u8s(queryText->text());
+    auto u8 = qs2u8s(queryText->text());
     trimstring(u8);
     if (u8.length() == 0)
         return;
@@ -534,8 +540,7 @@ void SSearch::startSimpleSearch()
         prefs.ssearchHistory.removeDuplicates();
     }
     if (prefs.historysize >= 0) {
-        for (int i = (int)prefs.ssearchHistory.count();
-             i > prefs.historysize; i--) {
+        for (int i = (int)prefs.ssearchHistory.count(); i > prefs.historysize; i--) {
             prefs.ssearchHistory.removeLast();
         }
     }
@@ -545,30 +550,29 @@ void SSearch::setPrefs()
 {
 }
 
-string SSearch::asXML()
+std::string SSearch::asXML()
 {
     return m_xml;
 }
 
-bool SSearch::startSimpleSearch(const string& u8, int maxexp)
+bool SSearch::startSimpleSearch(const std::string& u8, int maxexp)
 {
     LOGDEB("SSearch::startSimpleSearch(" << u8 << ")\n");
-    string stemlang = prefs.stemlang();
+    auto stemlang = prefs.stemlang();
 
-    ostringstream xml;
+    std::ostringstream xml;
     xml << "<SD type='ssearch'>\n";
     xml << "  <SL>" << stemlang << "</SL>\n";
     xml << "  <T>" << base64_encode(u8) << "</T>\n";
 
-    SSearchType tp = (SSearchType)searchTypCMB->currentIndex();
+    auto tp = getSearchType();
     std::shared_ptr<Rcl::SearchData> sdata;
 
     if (tp == SST_LANG) {
         xml << "  <SM>QL</SM>\n";
-        string reason;
+        std::string reason;
         if (prefs.autoSuffsEnable) {
-            sdata = wasaStringToRcl(theconfig, stemlang, u8, reason, 
-                                    (const char *)prefs.autoSuffs.toUtf8());
+            sdata = wasaStringToRcl(theconfig, stemlang, u8, reason, qs2u8s(prefs.autoSuffs));
             if (!prefs.autoSuffs.isEmpty()) {
                 xml <<  "  <AS>" << qs2u8s(prefs.autoSuffs) << "</AS>\n";
             }
@@ -576,8 +580,7 @@ bool SSearch::startSimpleSearch(const string& u8, int maxexp)
             sdata = wasaStringToRcl(theconfig, stemlang, u8, reason);
         }
         if (!sdata) {
-            QMessageBox::warning(0, "Recoll", tr("Bad query string") + ": " +
-                                 QString::fromUtf8(reason.c_str()));
+            QMessageBox::warning(0, "Recoll", tr("Bad query string") + ": " + u8s2qs(reason));
             return false;
         }
     } else {
@@ -633,8 +636,7 @@ bool SSearch::checkExtIndexes(const std::vector<std::string>& dbs)
 {
     std::string reason;
     if (!maybeOpenDb(reason, false)) {
-        QMessageBox::critical(0, "Recoll", tr("Can't open index") +
-                              u8s2qs(reason));
+        QMessageBox::critical(0, "Recoll", tr("Can't open index") + u8s2qs(reason));
         return false;
     }
     if (!rcldb->setExtraQueryDbs(dbs)) {
@@ -645,15 +647,15 @@ bool SSearch::checkExtIndexes(const std::vector<std::string>& dbs)
 
 bool SSearch::fromXML(const SSearchDef& fxml)
 {
-    string asString;
-    set<string> cur;
-    set<string> stored;
+    std::string asString;
+    std::set<std::string> cur;
+    std::set<std::string> stored;
 
     // Retrieve current list of stemlangs. prefs returns a
     // space-separated list Warn if stored differs from current,
     // but don't change the latter.
     stringToStrings(prefs.stemlang(), cur);
-    stored = set<string>(fxml.stemlangs.begin(), fxml.stemlangs.end());
+    stored = std::set<std::string>(fxml.stemlangs.begin(), fxml.stemlangs.end());
     stringsToString(fxml.stemlangs, asString);
     if (cur != stored) {
         QMessageBox::warning(
@@ -664,7 +666,7 @@ bool SSearch::fromXML(const SSearchDef& fxml)
 
     // Same for autosuffs
     stringToStrings(qs2u8s(prefs.autoSuffs), cur);
-    stored = set<string>(fxml.autosuffs.begin(), fxml.autosuffs.end());
+    stored = std::set<std::string>(fxml.autosuffs.begin(), fxml.autosuffs.end());
     stringsToString(fxml.stemlangs, asString);
     if (cur != stored) {
         QMessageBox::warning(
@@ -673,7 +675,6 @@ bool SSearch::fromXML(const SSearchDef& fxml)
             tr(" differ from current preferences (kept)"));
     }
 
-
     if (!checkExtIndexes(fxml.extindexes)) {
         stringsToString(fxml.extindexes, asString);
         QMessageBox::warning(
@@ -681,7 +682,7 @@ bool SSearch::fromXML(const SSearchDef& fxml)
             tr("Could not restore external indexes for stored query:<br> ") +
             (rcldb ? u8s2qs(rcldb->getReason()) : tr("???")) + QString("<br>") +
             tr("Using current preferences."));
-        string s;
+        std::string s;
         maybeOpenDb(s, true);
     } else {
         prefs.useTmpActiveExtraDbs = true;
@@ -715,38 +716,34 @@ bool SSearch::hasSearchString()
     return !currentText().isEmpty();
 }
 
-// Add term to simple search. Term comes out of double-click in
-// reslist or preview. 
-// It would probably be better to cleanup in preview.ui.h and
-// reslist.cpp and do the proper html stuff in the latter case
-// (which is different because it format is explicit richtext
-// instead of auto as for preview, needed because it's built by
-// fragments?).
+// Add term to simple search. Term comes out of double-click in reslist or preview.
+// It would probably be better to cleanup in preview.ui.h and reslist.cpp and do the proper html
+// stuff in the latter case (which is different because it format is explicit richtext instead of
+// auto as for preview, needed because it's built by fragments?).
 static const char* punct = " \t()<>\"'[]{}!^*.,:;\n\r";
 void SSearch::addTerm(QString term)
 {
-    LOGDEB("SSearch::AddTerm: [" << qs2u8s(term) << "]\n");
-    string t = (const char *)term.toUtf8();
-    string::size_type pos = t.find_last_not_of(punct);
-    if (pos == string::npos)
+    auto t = qs2u8s(term);
+    LOGDEB("SSearch::AddTerm: [" << t << "]\n");
+    std::string::size_type pos = t.find_last_not_of(punct);
+    if (pos == std::string::npos)
         return;
     t = t.substr(0, pos+1);
     pos = t.find_first_not_of(punct);
-    if (pos != string::npos)
+    if (pos != std::string::npos)
         t = t.substr(pos);
     if (t.empty())
         return;
-    term = QString::fromUtf8(t.c_str());
+    term = u8s2qs(t);
 
     QString text = currentText();
-    text += QString::fromLatin1(" ") + term;
+    text += " " + term;
     queryText->setText(text);
 }
 
 void SSearch::onWordReplace(const QString& o, const QString& n)
 {
-    LOGDEB("SSearch::onWordReplace: o [" << qs2u8s(o) << "] n [" <<
-           qs2u8s(n) << "]\n");
+    LOGDEB("SSearch::onWordReplace: o [" << qs2u8s(o) << "] n [" << qs2u8s(n) << "]\n");
     QString txt = currentText();
     QRegularExpression exp(QString("\\b") + o + QString("\\b"),
                            QRegularExpression::CaseInsensitiveOption);
