@@ -278,9 +278,9 @@ WebcacheEdit::WebcacheEdit(RclMain *parent)
 void WebcacheEdit::onHeaderChanged(WebStore *ws)
 {
     headerInfoLBL->setText(tr("Maximum size %1 (Index config.). Current size %2. Write position %3.")
-                           .arg(u8s2qs(displayableBytes(ws->cc()->maxsize())))
-                           .arg(u8s2qs(displayableBytes(ws->cc()->size())))
-                           .arg(u8s2qs(displayableBytes(ws->cc()->writepos())))
+                           .arg(u8s2qs(displayableBytes(ws->cc()->maxsize())),
+                                u8s2qs(displayableBytes(ws->cc()->size())), 
+                                u8s2qs(displayableBytes(ws->cc()->writepos())))
         );
 }
 
@@ -362,7 +362,7 @@ void WebcacheEdit::saveColState()
     QStringList newwidths;
     for (int vi = 0; vi < header->count(); vi++) {
         int li = header->logicalIndex(vi);
-        newwidths.push_back(lltodecstr(header->sectionSize(li)).c_str());
+        newwidths.push_back(std::to_string(header->sectionSize(li)).c_str());
     }
     QSettings settings;
     settings.setValue(cwnm, newwidths);
