@@ -14,12 +14,7 @@
  *   Free Software Foundation, Inc.,
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
-#ifdef BUILDING_RECOLL
-#include "autoconfig.h"
-#else
-#include "config.h"
-#endif
-
+#define _FILE_OFFSET_BITS 64
 #include "conftree.h"
 
 #include <ctype.h>
@@ -431,7 +426,7 @@ int ConfSimple::set(const std::string& nm, const std::string& value, const std::
 
 int ConfSimple::set(const std::string& nm, long long val, const std::string& sk)
 {
-    return this->set(nm, lltodecstr(val), sk);
+    return this->set(nm, std::to_string(val), sk);
 }
 
 // Internal set variable: no rw checking or file rewriting. If init is
